from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.error_code import ErrorCode
from ..types import UNSET, Unset

MS = TypeVar("MS", bound="Error")


@attr.s(auto_attribs=True)
class Error:
    """An error."""  # noqa: E501

    code: Union[Unset, ErrorCode] = UNSET
    message: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.code, Unset):
            code = self.code
        message = self.message

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if code is not UNSET:
            field_dict["code"] = code
        if message is not UNSET:
            field_dict["message"] = message

        return field_dict

    @classmethod
    def from_dict(cls: Type[MS], src_dict: Dict[str, Any]) -> MS:
        d = src_dict.copy()
        _code = d.pop("code", UNSET)
        code: Union[Unset, ErrorCode]
        if isinstance(_code, Unset):
            code = UNSET
        else:
            code = _code  # type: ignore[arg-type]

        message = d.pop("message", UNSET)

        error = cls(
            code=code,
            message=message,
        )

        error.additional_properties = d
        return error

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

LT = TypeVar("LT", bound="ErrorResponse")


@attr.s(auto_attribs=True)
class ErrorResponse:
    """The error response."""  # noqa: E501

    from ..models.error import Error

    errors: Union[Unset, List[Error]] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.error import Error

        errors: Union[Unset, List[Error]] = UNSET
        if not isinstance(self.errors, Unset):
            errors = self.errors

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if errors is not UNSET:
            field_dict["errors"] = errors

        return field_dict

    @classmethod
    def from_dict(cls: Type[LT], src_dict: Dict[str, Any]) -> LT:
        d = src_dict.copy()
        from ..models.error import Error

        errors = cast(List[Error], d.pop("errors", UNSET))

        error_response = cls(
            errors=errors,
        )

        error_response.additional_properties = d
        return error_response

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RtcIceProtocol(str, Enum):
    """ICEProtocol indicates the transport protocol type that is used in the ice.URL structure."""  # noqa: E501

    """# Unspecified indicates that the protocol is unspecified. """  # noqa: E501
    UNSPECIFIED = "unspecified"
    """# UDP indicates the URL uses a UDP transport. """  # noqa: E501
    UDP = "udp"
    """# TCP indicates the URL uses a TCP transport. """  # noqa: E501
    TCP = "tcp"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

YY = TypeVar("YY", bound="ExportFile")


@attr.s(auto_attribs=True)
class ExportFile:
    """A file to be exported to the client."""  # noqa: E501

    contents: Union[Unset, str] = UNSET
    name: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        contents = self.contents
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if contents is not UNSET:
            field_dict["contents"] = contents
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[YY], src_dict: Dict[str, Any]) -> YY:
        d = src_dict.copy()
        contents = d.pop("contents", UNSET)

        name = d.pop("name", UNSET)

        export_file = cls(
            contents=contents,
            name=name,
        )

        export_file.additional_properties = d
        return export_file

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class ErrorCode(str, Enum):
    """The type of errorcode."""  # noqa: E501

    """# User requested something impossible or invalid """  # noqa: E501
    BAD_REQUEST = "bad_request"
    """# Engine failed to complete request, consider retrying """  # noqa: E501
    INTERNAL_ENGINE = "internal_engine"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.modeling_cmd import ModelingCmd
from ..models.modeling_cmd_id import ModelingCmdId
from ..models.rtc_ice_candidate_init import RtcIceCandidateInit
from ..models.rtc_session_description import RtcSessionDescription
from ..types import UNSET, Unset

AX = TypeVar("AX", bound="trickle_ice")


@attr.s(auto_attribs=True)
class trickle_ice:
    """The trickle ICE candidate request."""  # noqa: E501

    candidate: Union[Unset, RtcIceCandidateInit] = UNSET
    type: str = "trickle_ice"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.candidate, Unset):
            candidate = self.candidate
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if candidate is not UNSET:
            field_dict["candidate"] = candidate
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[AX], src_dict: Dict[str, Any]) -> AX:
        d = src_dict.copy()
        _candidate = d.pop("candidate", UNSET)
        candidate: Union[Unset, RtcIceCandidateInit]
        if isinstance(_candidate, Unset):
            candidate = UNSET
        else:
            candidate = _candidate  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        trickle_ice = cls(
            candidate=candidate,
            type=type,
        )

        trickle_ice.additional_properties = d
        return trickle_ice

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


RQ = TypeVar("RQ", bound="sdp_offer")


@attr.s(auto_attribs=True)
class sdp_offer:
    """The SDP offer request."""  # noqa: E501

    offer: Union[Unset, RtcSessionDescription] = UNSET
    type: str = "sdp_offer"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.offer, Unset):
            offer = self.offer
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if offer is not UNSET:
            field_dict["offer"] = offer
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[RQ], src_dict: Dict[str, Any]) -> RQ:
        d = src_dict.copy()
        _offer = d.pop("offer", UNSET)
        offer: Union[Unset, RtcSessionDescription]
        if isinstance(_offer, Unset):
            offer = UNSET
        else:
            offer = _offer  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        sdp_offer = cls(
            offer=offer,
            type=type,
        )

        sdp_offer.additional_properties = d
        return sdp_offer

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


ZL = TypeVar("ZL", bound="modeling_cmd_req")


@attr.s(auto_attribs=True)
class modeling_cmd_req:
    """The modeling command request."""  # noqa: E501

    cmd: Union[Unset, ModelingCmd] = UNSET
    cmd_id: Union[Unset, ModelingCmdId] = UNSET
    type: str = "modeling_cmd_req"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.cmd, Unset):
            cmd = self.cmd
        if not isinstance(self.cmd_id, Unset):
            cmd_id = self.cmd_id
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cmd is not UNSET:
            field_dict["cmd"] = cmd
        if cmd_id is not UNSET:
            field_dict["cmd_id"] = cmd_id
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[ZL], src_dict: Dict[str, Any]) -> ZL:
        d = src_dict.copy()
        _cmd = d.pop("cmd", UNSET)
        cmd: Union[Unset, ModelingCmd]
        if isinstance(_cmd, Unset):
            cmd = UNSET
        else:
            cmd = _cmd  # type: ignore[arg-type]

        _cmd_id = d.pop("cmd_id", UNSET)
        cmd_id: Union[Unset, ModelingCmdId]
        if isinstance(_cmd_id, Unset):
            cmd_id = UNSET
        else:
            cmd_id = _cmd_id  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        modeling_cmd_req = cls(
            cmd=cmd,
            cmd_id=cmd_id,
            type=type,
        )

        modeling_cmd_req.additional_properties = d
        return modeling_cmd_req

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


WebSocketMessages = Union[trickle_ice, sdp_offer, modeling_cmd_req]



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..types import UNSET, Unset

TF = TypeVar("TF", bound="RtcIceCandidateInit")


@attr.s(auto_attribs=True)
class RtcIceCandidateInit:
    """ICECandidateInit is used to serialize ice candidates"""  # noqa: E501

    candidate: Union[Unset, str] = UNSET
    sdp_m_line_index: Union[Unset, int] = UNSET
    sdp_mid: Union[Unset, str] = UNSET
    username_fragment: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        candidate = self.candidate
        sdp_m_line_index = self.sdp_m_line_index
        sdp_mid = self.sdp_mid
        username_fragment = self.username_fragment

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if candidate is not UNSET:
            field_dict["candidate"] = candidate
        if sdp_m_line_index is not UNSET:
            field_dict["sdpMLineIndex"] = sdp_m_line_index
        if sdp_mid is not UNSET:
            field_dict["sdpMid"] = sdp_mid
        if username_fragment is not UNSET:
            field_dict["usernameFragment"] = username_fragment

        return field_dict

    @classmethod
    def from_dict(cls: Type[TF], src_dict: Dict[str, Any]) -> TF:
        d = src_dict.copy()
        candidate = d.pop("candidate", UNSET)

        sdp_m_line_index = d.pop("sdpMLineIndex", UNSET)

        sdp_mid = d.pop("sdpMid", UNSET)

        username_fragment = d.pop("usernameFragment", UNSET)

        rtc_ice_candidate_init = cls(
            candidate=candidate,
            sdp_m_line_index=sdp_m_line_index,
            sdp_mid=sdp_mid,
            username_fragment=username_fragment,
        )

        rtc_ice_candidate_init.additional_properties = d
        return rtc_ice_candidate_init

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from enum import Enum


class RtcIceCandidateType(str, Enum):
    """ICECandidateType represents the type of the ICE candidate used."""  # noqa: E501

    """# Unspecified indicates that the candidate type is unspecified. """  # noqa: E501
    UNSPECIFIED = "unspecified"
    """# ICECandidateTypeHost indicates that the candidate is of Host type as described in <https://tools.ietf.org/html/rfc8445#section-5.1.1.1>. A candidate obtained by binding to a specific port from an IP address on the host. This includes IP addresses on physical interfaces and logical ones, such as ones obtained through VPNs. """  # noqa: E501
    HOST = "host"
    """# ICECandidateTypeSrflx indicates the the candidate is of Server Reflexive type as described <https://tools.ietf.org/html/rfc8445#section-5.1.1.2>. A candidate type whose IP address and port are a binding allocated by a NAT for an ICE agent after it sends a packet through the NAT to a server, such as a STUN server. """  # noqa: E501
    SRFLX = "srflx"
    """# ICECandidateTypePrflx indicates that the candidate is of Peer Reflexive type. A candidate type whose IP address and port are a binding allocated by a NAT for an ICE agent after it sends a packet through the NAT to its peer. """  # noqa: E501
    PRFLX = "prflx"
    """# ICECandidateTypeRelay indicates the the candidate is of Relay type as described in <https://tools.ietf.org/html/rfc8445#section-5.1.1.2>. A candidate type obtained from a relay server, such as a TURN server. """  # noqa: E501
    RELAY = "relay"

    def __str__(self) -> str:
        return str(self.value)



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..models.modeling_cmd_id import ModelingCmdId
from ..models.rtc_ice_candidate import RtcIceCandidate
from ..models.rtc_session_description import RtcSessionDescription
from ..models.snake_case_result import SnakeCaseResult
from ..types import UNSET, Unset

CM = TypeVar("CM", bound="trickle_ice")


@attr.s(auto_attribs=True)
class trickle_ice:
    """The trickle ICE candidate response."""  # noqa: E501

    candidate: Union[Unset, RtcIceCandidate] = UNSET
    type: str = "trickle_ice"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.candidate, Unset):
            candidate = self.candidate
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if candidate is not UNSET:
            field_dict["candidate"] = candidate
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[CM], src_dict: Dict[str, Any]) -> CM:
        d = src_dict.copy()
        _candidate = d.pop("candidate", UNSET)
        candidate: Union[Unset, RtcIceCandidate]
        if isinstance(_candidate, Unset):
            candidate = UNSET
        else:
            candidate = _candidate  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        trickle_ice = cls(
            candidate=candidate,
            type=type,
        )

        trickle_ice.additional_properties = d
        return trickle_ice

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


OS = TypeVar("OS", bound="sdp_answer")


@attr.s(auto_attribs=True)
class sdp_answer:
    """The SDP answer response."""  # noqa: E501

    answer: Union[Unset, RtcSessionDescription] = UNSET
    type: str = "sdp_answer"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.answer, Unset):
            answer = self.answer
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if answer is not UNSET:
            field_dict["answer"] = answer
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[OS], src_dict: Dict[str, Any]) -> OS:
        d = src_dict.copy()
        _answer = d.pop("answer", UNSET)
        answer: Union[Unset, RtcSessionDescription]
        if isinstance(_answer, Unset):
            answer = UNSET
        else:
            answer = _answer  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        sdp_answer = cls(
            answer=answer,
            type=type,
        )

        sdp_answer.additional_properties = d
        return sdp_answer

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


WP = TypeVar("WP", bound="ice_server_info")


@attr.s(auto_attribs=True)
class ice_server_info:
    """The ICE server info response."""  # noqa: E501

    from ..models.ice_server import IceServer

    ice_servers: Union[Unset, List[IceServer]] = UNSET
    type: str = "ice_server_info"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.ice_server import IceServer

        ice_servers: Union[Unset, List[IceServer]] = UNSET
        if not isinstance(self.ice_servers, Unset):
            ice_servers = self.ice_servers
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if ice_servers is not UNSET:
            field_dict["ice_servers"] = ice_servers
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[WP], src_dict: Dict[str, Any]) -> WP:
        d = src_dict.copy()
        from ..models.ice_server import IceServer

        ice_servers = cast(List[IceServer], d.pop("ice_servers", UNSET))

        type = d.pop("type", UNSET)

        ice_server_info = cls(
            ice_servers=ice_servers,
            type=type,
        )

        ice_server_info.additional_properties = d
        return ice_server_info

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


XO = TypeVar("XO", bound="modeling")


@attr.s(auto_attribs=True)
class modeling:
    """The modeling command response."""  # noqa: E501

    cmd_id: Union[Unset, ModelingCmdId] = UNSET
    result: Union[Unset, SnakeCaseResult] = UNSET
    type: str = "modeling"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        if not isinstance(self.cmd_id, Unset):
            cmd_id = self.cmd_id
        if not isinstance(self.result, Unset):
            result = self.result
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if cmd_id is not UNSET:
            field_dict["cmd_id"] = cmd_id
        if result is not UNSET:
            field_dict["result"] = result
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[XO], src_dict: Dict[str, Any]) -> XO:
        d = src_dict.copy()
        _cmd_id = d.pop("cmd_id", UNSET)
        cmd_id: Union[Unset, ModelingCmdId]
        if isinstance(_cmd_id, Unset):
            cmd_id = UNSET
        else:
            cmd_id = _cmd_id  # type: ignore[arg-type]

        _result = d.pop("result", UNSET)
        result: Union[Unset, SnakeCaseResult]
        if isinstance(_result, Unset):
            result = UNSET
        else:
            result = _result  # type: ignore[arg-type]

        type = d.pop("type", UNSET)

        modeling = cls(
            cmd_id=cmd_id,
            result=result,
            type=type,
        )

        modeling.additional_properties = d
        return modeling

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


LN = TypeVar("LN", bound="export")


@attr.s(auto_attribs=True)
class export:
    """The export command response, this is sent as binary."""  # noqa: E501

    from ..models.raw_file import RawFile

    files: Union[Unset, List[RawFile]] = UNSET
    type: str = "export"

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        from ..models.raw_file import RawFile

        files: Union[Unset, List[RawFile]] = UNSET
        if not isinstance(self.files, Unset):
            files = self.files
        type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if files is not UNSET:
            field_dict["files"] = files
        field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[LN], src_dict: Dict[str, Any]) -> LN:
        d = src_dict.copy()
        from ..models.raw_file import RawFile

        files = cast(List[RawFile], d.pop("files", UNSET))

        type = d.pop("type", UNSET)

        export = cls(
            files=files,
            type=type,
        )

        export.additional_properties = d
        return export

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties


WebSocketResponses = Union[trickle_ice, sdp_answer, ice_server_info, modeling, export]



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.rtc_sdp_type import RtcSdpType
from ..types import UNSET, Unset

HF = TypeVar("HF", bound="RtcSessionDescription")


@attr.s(auto_attribs=True)
class RtcSessionDescription:
    """SessionDescription is used to expose local and remote session descriptions."""  # noqa: E501

    sdp: Union[Unset, str] = UNSET
    type: Union[Unset, RtcSdpType] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        sdp = self.sdp
        if not isinstance(self.type, Unset):
            type = self.type

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if sdp is not UNSET:
            field_dict["sdp"] = sdp
        if type is not UNSET:
            field_dict["type"] = type

        return field_dict

    @classmethod
    def from_dict(cls: Type[HF], src_dict: Dict[str, Any]) -> HF:
        d = src_dict.copy()
        sdp = d.pop("sdp", UNSET)

        _type = d.pop("type", UNSET)
        type: Union[Unset, RtcSdpType]
        if isinstance(_type, Unset):
            type = UNSET
        else:
            type = _type  # type: ignore[arg-type]

        rtc_session_description = cls(
            sdp=sdp,
            type=type,
        )

        rtc_session_description.additional_properties = d
        return rtc_session_description

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

CX = TypeVar("CX", bound="RawFile")


@attr.s(auto_attribs=True)
class RawFile:
    """A raw file with unencoded contents to be passed over binary websockets."""  # noqa: E501

    contents: Union[Unset, List[int]] = UNSET
    name: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        contents: Union[Unset, List[int]] = UNSET
        if not isinstance(self.contents, Unset):
            contents = self.contents
        name = self.name

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if contents is not UNSET:
            field_dict["contents"] = contents
        if name is not UNSET:
            field_dict["name"] = name

        return field_dict

    @classmethod
    def from_dict(cls: Type[CX], src_dict: Dict[str, Any]) -> CX:
        d = src_dict.copy()
        contents = cast(List[int], d.pop("contents", UNSET))

        name = d.pop("name", UNSET)

        raw_file = cls(
            contents=contents,
            name=name,
        )

        raw_file.additional_properties = d
        return raw_file

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union, cast

import attr

from ..types import UNSET, Unset

UF = TypeVar("UF", bound="IceServer")


@attr.s(auto_attribs=True)
class IceServer:
    """Representation of an ICE server used for STUN/TURN Used to initiate WebRTC connections based on <https://developer.mozilla.org/en-US/docs/Web/API/RTCIceServer>"""  # noqa: E501

    credential: Union[Unset, str] = UNSET
    urls: Union[Unset, List[str]] = UNSET
    username: Union[Unset, str] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        credential = self.credential
        urls: Union[Unset, List[str]] = UNSET
        if not isinstance(self.urls, Unset):
            urls = self.urls
        username = self.username

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if credential is not UNSET:
            field_dict["credential"] = credential
        if urls is not UNSET:
            field_dict["urls"] = urls
        if username is not UNSET:
            field_dict["username"] = username

        return field_dict

    @classmethod
    def from_dict(cls: Type[UF], src_dict: Dict[str, Any]) -> UF:
        d = src_dict.copy()
        credential = d.pop("credential", UNSET)

        urls = cast(List[str], d.pop("urls", UNSET))

        username = d.pop("username", UNSET)

        ice_server = cls(
            credential=credential,
            urls=urls,
            username=username,
        )

        ice_server.additional_properties = d
        return ice_server

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties



from typing import Any, Dict, List, Type, TypeVar, Union

import attr

from ..models.rtc_ice_candidate_type import RtcIceCandidateType
from ..models.rtc_ice_protocol import RtcIceProtocol
from ..types import UNSET, Unset

LJ = TypeVar("LJ", bound="RtcIceCandidate")


@attr.s(auto_attribs=True)
class RtcIceCandidate:
    """ICECandidate represents a ice candidate"""  # noqa: E501

    address: Union[Unset, str] = UNSET
    component: Union[Unset, int] = UNSET
    foundation: Union[Unset, str] = UNSET
    port: Union[Unset, int] = UNSET
    priority: Union[Unset, int] = UNSET
    protocol: Union[Unset, RtcIceProtocol] = UNSET
    related_address: Union[Unset, str] = UNSET
    related_port: Union[Unset, int] = UNSET
    stats_id: Union[Unset, str] = UNSET
    tcp_type: Union[Unset, str] = UNSET
    typ: Union[Unset, RtcIceCandidateType] = UNSET

    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)

    def to_dict(self) -> Dict[str, Any]:
        address = self.address
        component = self.component
        foundation = self.foundation
        port = self.port
        priority = self.priority
        if not isinstance(self.protocol, Unset):
            protocol = self.protocol
        related_address = self.related_address
        related_port = self.related_port
        stats_id = self.stats_id
        tcp_type = self.tcp_type
        if not isinstance(self.typ, Unset):
            typ = self.typ

        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({})
        if address is not UNSET:
            field_dict["address"] = address
        if component is not UNSET:
            field_dict["component"] = component
        if foundation is not UNSET:
            field_dict["foundation"] = foundation
        if port is not UNSET:
            field_dict["port"] = port
        if priority is not UNSET:
            field_dict["priority"] = priority
        if protocol is not UNSET:
            field_dict["protocol"] = protocol
        if related_address is not UNSET:
            field_dict["related_address"] = related_address
        if related_port is not UNSET:
            field_dict["related_port"] = related_port
        if stats_id is not UNSET:
            field_dict["stats_id"] = stats_id
        if tcp_type is not UNSET:
            field_dict["tcp_type"] = tcp_type
        if typ is not UNSET:
            field_dict["typ"] = typ

        return field_dict

    @classmethod
    def from_dict(cls: Type[LJ], src_dict: Dict[str, Any]) -> LJ:
        d = src_dict.copy()
        address = d.pop("address", UNSET)

        component = d.pop("component", UNSET)

        foundation = d.pop("foundation", UNSET)

        port = d.pop("port", UNSET)

        priority = d.pop("priority", UNSET)

        _protocol = d.pop("protocol", UNSET)
        protocol: Union[Unset, RtcIceProtocol]
        if isinstance(_protocol, Unset):
            protocol = UNSET
        else:
            protocol = _protocol  # type: ignore[arg-type]

        related_address = d.pop("related_address", UNSET)

        related_port = d.pop("related_port", UNSET)

        stats_id = d.pop("stats_id", UNSET)

        tcp_type = d.pop("tcp_type", UNSET)

        _typ = d.pop("typ", UNSET)
        typ: Union[Unset, RtcIceCandidateType]
        if isinstance(_typ, Unset):
            typ = UNSET
        else:
            typ = _typ  # type: ignore[arg-type]

        rtc_ice_candidate = cls(
            address=address,
            component=component,
            foundation=foundation,
            port=port,
            priority=priority,
            protocol=protocol,
            related_address=related_address,
            related_port=related_port,
            stats_id=stats_id,
            tcp_type=tcp_type,
            typ=typ,
        )

        rtc_ice_candidate.additional_properties = d
        return rtc_ice_candidate

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
